@@ -33,7 +33,10 @@ from collections import defaultdict
 from collections.abc import Mapping
 from dataclasses import asdict
 from datetime import datetime
-from distutils.util import strtobool
+# Comment below disabling pylint checks is due to a bug in the CircleCi image with Pylint
+# It seems to be unable to import the distutils module, however the module is present and importable
+# in the Python Repl.
+from distutils.util import strtobool #pylint: disable=E0611, E0401
 from fnmatch import fnmatch
 from importlib.abc import Loader
 from typing import Any, DefaultDict, Dict, Iterator, List, Set, Tuple, Type
@@ -1309,7 +1312,7 @@ def setup_parser() -> argparse.ArgumentParser:
         + "managing Panther policies and rules.",
         prog="panther_analysis_tool",
     )
-    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.10.4")
+    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.10.6")
     parser.add_argument("--debug", action="store_true", dest="debug")
     subparsers = parser.add_subparsers()
 
@@ -1466,8 +1469,8 @@ def dynaconf_argparse_merge(
 
 # Parses the filters, expects a list of strings
 def parse_filter(filters: List[str]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
-    parsed_filters = {}
-    parsed_filters_inverted = {}
+    parsed_filters: Dict[str, Any] = {}
+    parsed_filters_inverted: Dict[str, Any] = {}
     for filt in filters:
         split = filt.split("=")
         if len(split) != 2 or split[0] == "" or split[1] == "":
@@ -1495,6 +1498,17 @@ def parse_filter(filters: List[str]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
             parsed_filters_inverted[key] = split[1].split(",")
         else:
             parsed_filters[key] = split[1].split(",")
+        # Handle boolean fields
+        if key == "Enabled":
+            try:
+                bool_value = bool(strtobool(split[1]))
+            except ValueError:
+                logging.warning("Filter key %s should have either true or false, skipping", key)
+                continue
+            if invert_filter:
+                parsed_filters_inverted[key] = [bool_value]
+            else:
+                parsed_filters[key] = [bool_value]
     return parsed_filters, parsed_filters_inverted
 
 
